# -*- coding: utf-8 -*-
from __future__ import unicode_literals

MAX_PREFIX_LENGTH = 16
MAX_KEY_LENGTH = 32
GLOBAL_PREFIX = 'sessions'
DATA_KEY = 'd'
INFO_KEY = 'i'
DEFAULT_PREFIX = 'default'
INFO_EXIST_VALUE = 1
IP_KEY = 'ip'
SESSION_PROCESSED = 'session_processed'
META_IP = 'REMOTE_ADDR'
META_AGENT = 'HTTP_USER_AGENT'
